Class: GraphqlMigrateExecution::DataloaderManual
- Defined in:
- lib/graphql_migrate_execution/dataloader_manual.rb
Overview
These fields use Dataloader in a way that can’t be automatically migrated. You’ll have to migrate them manually. If you have a lot of these, consider opening up an issue on GraphQL-Ruby – maybe we can find a way to programmatically support them.
Constant Summary
Constants inherited from Strategy
Method Summary
Methods inherited from Strategy
#cleanup, #initialize, #migrate, prefix_if_necessary, #run, strategy_name
Constructor Details
This class inherits a constructor from GraphqlMigrateExecution::Strategy